==================================
*argon2-cffi*: *Argon2* for Python
==================================

Release v\ |release| (|changelog|_)


.. include:: ../README.rst
   :start-after: -begin-short-
   :end-before: -end-short-


User's Guide
============

.. toctree::
   :maxdepth: 1

   argon2
   installation
   api
   parameters
   cli
   faq


.. include:: ../README.rst
   :start-after: -begin-meta-
   :end-before: -end-meta-

.. toctree::
   :maxdepth: 1

   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
